Py4JException (py4j-java 0.10.0 API)
Date: 2016-04-18

py4j

## Class Py4JException

- java.lang.Object
- - java.lang.Throwable
  - - java.lang.Exception
    - - java.lang.RuntimeException
      - - py4j.Py4JException

- All Implemented Interfaces:
    java.io.Serializable
  Direct Known Subclasses:
    Py4JJavaException, Py4JNetworkException

      public class Py4JException
      extends java.lang.RuntimeException

  Exception raised when an error is encountered while using Py4J.

  See Also:
    Serialized Form

- - ### Constructor Summary

    Constructors
    Constructor and Description
    `Py4JException()`
    `Py4JException(java.lang.String arg0)`
    `Py4JException(java.lang.String arg0, java.lang.Throwable arg1)`
    `Py4JException(java.lang.Throwable arg0)`

  - ### Method Summary

    - ### Methods inherited from class java.lang.Throwable

      `addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

- - ### Constructor Detail

    - #### Py4JException

          public Py4JException()

    - #### Py4JException

          public Py4JException(java.lang.String arg0)

    - #### Py4JException

          public Py4JException(java.lang.String arg0,
                               java.lang.Throwable arg1)

    - #### Py4JException

          public Py4JException(java.lang.Throwable arg0)